@@ -1,26 +1,44 @@
 import re
 from typing import List, Optional, Any, Dict, _GenericAlias, Tuple
-from StructNoSQL.dynamodb.models import DatabasePathElement
+
+from StructNoSQL.middlewares.dynamodb.backend.dynamodb_utils import DynamoDBUtils
+from StructNoSQL.models import DatabasePathElement
 from StructNoSQL.exceptions import InvalidFieldNameException, UsageOfUntypedSetException
 from StructNoSQL.practical_logger import message_with_vars
 from StructNoSQL.query import Query
 from StructNoSQL.utils.types import ACCEPTABLE_KEY_TYPES
+from StructNoSQL.utils.misc_fields_items import make_dict_key_var_name, try_to_get_primitive_default_type_of_item
 
-FIELD_NAME_RESTRICTED_CHARS_LIST = ['[', ']', '{', '}', '(', ')' '|']
-FIELD_NAME_RESTRICTED_CHARS_EXPRESSION = r'(\[|\]|\{|\}|\(|\)|\|)'
+
+FIELD_NAME_RESTRICTED_CHARS_LIST = ['[', ']', '{', '}', '(', ')', '|']
+FIELD_NAME_RESTRICTED_CHARS_EXPRESSION = "|".join(re.escape(char) for char in FIELD_NAME_RESTRICTED_CHARS_LIST)
+# We escape each individual char, which will add the appropriate backslashes to the chars that require them.
+
+FIELD_NAME_RESTRICTED_NAMES_LIST = DynamoDBUtils.DYNAMODB_TYPES_KEYS
+FIELD_NAME_RESTRICTED_NAMES_EXPRESSION = f"^({'|'.join(name for name in FIELD_NAME_RESTRICTED_NAMES_LIST)})$"
 
 
 def _raise_if_field_name_is_invalid(field_name: str):
-    match: Optional[List[tuple]] = re.findall(pattern=FIELD_NAME_RESTRICTED_CHARS_EXPRESSION, string=field_name)
-    if match is not None and len(match) > 0:
+    restricted_chars_matches: Optional[List[tuple]] = re.findall(pattern=FIELD_NAME_RESTRICTED_CHARS_EXPRESSION, string=field_name)
+    if restricted_chars_matches is not None and len(restricted_chars_matches) > 0:
         raise InvalidFieldNameException(message_with_vars(
             message="A field name was using one or multiple restricted chars",
             vars_dict={
-                'fieldName': field_name, 'restrictedCharsMatch': match,
+                'fieldName': field_name, 'restrictedCharsMatch': restricted_chars_matches,
                 'FIELD_NAME_RESTRICTED_CHARS_LIST': FIELD_NAME_RESTRICTED_CHARS_LIST
             }
         ))
 
+    restricted_names_matches: Optional[List[tuple]] = re.findall(pattern=FIELD_NAME_RESTRICTED_NAMES_EXPRESSION, string=field_name)
+    if restricted_names_matches is not None and len(restricted_names_matches) > 0:
+        raise InvalidFieldNameException(message_with_vars(
+            message="A field name was using a restricted name",
+            vars_dict={
+                'fieldName': field_name, 'restricted_names_matches': restricted_names_matches,
+                'FIELD_NAME_RESTRICTED_NAMES_LIST': FIELD_NAME_RESTRICTED_NAMES_LIST
+            }
+        ))
+
 
 class BaseDataModel:
     def __init__(self):
@@ -166,7 +184,7 @@ class BaseItem:
         # self.validate_data()
         # print("Finished data validation.")
 
-    def query(self, key_value: str, fields_paths_elements: List[str], index_name: Optional[str] = None, query_kwargs: Optional[dict] = None) -> Query:
+    def query(self, key_value: str, fields_path_elements: List[str], index_name: Optional[str] = None, query_kwargs: Optional[dict] = None) -> Query:
         """for path_element in self._database_path:
             if "$key$:" in path_element.element_key:
                 variable_name = path_element.element_key.replace("$key$:", "")
@@ -339,7 +357,6 @@ class MapItem(BaseField):
         super().__init__(name=None, field_type=field_type, custom_default_value=BaseItem.instantiate_default_value_type(field_type))
         self.map_model = model_type
 
-        from StructNoSQL.tables.base_table import make_dict_key_var_name, try_to_get_primitive_default_type_of_item
         element_key = make_dict_key_var_name(parent_field.key_name)
         default_type = try_to_get_primitive_default_type_of_item(parent_field.items_excepted_type)
         database_path_element = DatabasePathElement(element_key=element_key, default_type=default_type)
